@@ -244,9 +244,6 @@ static int LoadGPUplugin(const char *GPUdll) {
 	LoadGpuSym0(configure, "GPUconfigure");
 	LoadGpuSym0(test, "GPUtest");
 	LoadGpuSym0(about, "GPUabout");
-	
-	extern unsigned long gpuDisp;
-	int ret = GPU_open(&gpuDisp, "PCSX", NULL);
 
 	return 0;
 }
