@@ -22,8 +22,17 @@
 #define D_WIDTH			640
 #define D_HEIGHT		480
 
+#define CALL_SIGNAL_IF "com.nokia.csd.Call"
+#define CALL_SIGNAL_PATH "/com/nokia/csd/call"
+#define CALL_INCOMING_SIG "Coming"
+
+#define DBUS_RULE_CALL_INCOMING "type='signal',interface='" CALL_SIGNAL_IF \
+                                "',path='" CALL_SIGNAL_PATH \
+                                "',member='" CALL_INCOMING_SIG "'"
+
 osso_context_t* osso;
 extern int bKeepDisplayOn;
+extern char keys_config_file[MAXPATHLEN];
 static pthread_t display_thread = (pthread_t)-1;
 int g_layer_x = (X_RES - D_WIDTH) / 2;
 int g_layer_y = (Y_RES - D_HEIGHT) / 2;
@@ -48,14 +57,15 @@ static const unsigned char keymap2[14] = {
 	DKEY_SQUARE,
 	DKEY_SELECT,
 	DKEY_START,
-	DKEY_L2,     // 10
-	DKEY_R2,
-	DKEY_L1,
+	DKEY_L1,     // 10
 	DKEY_R1,
+	DKEY_L2,
+	DKEY_R2,
 };
 
 void hildon_quit()
 {
+	maemo_finish();
 	gtk_main_quit();
 	exit(0);
 }
@@ -68,7 +78,7 @@ window_key_proxy(GtkWidget *widget,
 	return key_press_event(event->hardware_keycode, event->type == GDK_KEY_PRESS?1:(event->type == GDK_KEY_RELEASE?2:0) );
 }
 
-static void displayThread(void *arg)
+static void *displayThread(void *arg)
 {
 	DBusConnection* system_bus = (DBusConnection*)osso_get_sys_dbus_connection(osso);
 	DBusMessage* msg = dbus_message_new_method_call("com.nokia.mce", 
@@ -82,6 +92,8 @@ static void displayThread(void *arg)
 			usleep(4000000);
 		}
 	}
+
+	return 0;
 }
 
 void show_notification(char* text)
@@ -103,11 +115,22 @@ void show_notification(char* text)
 	}
 }
 
+void show_messagebox(char* text)
+{
+	GtkWidget *dialog;
+	dialog = gtk_message_dialog_new (GTK_WINDOW(window),
+									 GTK_DIALOG_DESTROY_WITH_PARENT,
+									 GTK_MESSAGE_INFO,
+									 GTK_BUTTONS_OK,
+									 text);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+}
+
 #include <hildon/hildon-file-chooser-dialog.h>
 void change_disc()
 {
 	GtkWidget *dialog;
-
 	dialog = hildon_file_chooser_dialog_new (GTK_WINDOW(window), GTK_FILE_CHOOSER_ACTION_OPEN);
 
 	char currentFile[MAXPATHLEN];
@@ -151,6 +174,16 @@ void change_disc()
 	gtk_widget_destroy (dialog);
 }
 
+static DBusHandlerResult on_msg_recieved(DBusConnection* connection G_GNUC_UNUSED, DBusMessage* message, void* data)
+{
+	if (g_str_equal(dbus_message_get_path(message), CALL_SIGNAL_PATH)){
+		if (g_str_equal(dbus_message_get_member(message), CALL_INCOMING_SIG))
+			show_messagebox("Paused");
+	}
+
+	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+}
+
 inline void key_press_event(int key2,int type)
 {
 	int  psxkey1 = -1, psxkey2 = -1;
@@ -249,12 +282,22 @@ void set_accel_multipliers()
 	accelOptions.yMultiplier = 255.0 / ( (accelOptions.maxValue - accelOptions.sens) * 2.0);
 }
 
-void maemo_init(int *argc, char ***argv)
+int maemo_init(int *argc, char ***argv)
 {
 	osso = osso_initialize("pcsxrearmed", PACKAGE_VERSION, FALSE, NULL);
 
+	DBusConnection* system_bus = (DBusConnection*)osso_get_sys_dbus_connection(osso);
+    dbus_bus_add_match(system_bus, DBUS_RULE_CALL_INCOMING, NULL);
+	dbus_connection_add_filter(system_bus, on_msg_recieved, NULL, NULL);
+
 	FILE* pFile;
-	pFile = fopen("/opt/psx4m/keys", "r"); // assume the file exists and has data
+	pFile = fopen(keys_config_file, "r");
+	if (pFile == NULL){
+		printf("Error opening keys config file %s\n", keys_config_file);
+		return 1;
+	}
+	printf("Keys config read from %s\n", keys_config_file);
+
 	int ch;
 	int i=0;
 	for (i=0;i<65536;i++)
@@ -303,6 +346,13 @@ void maemo_init(int *argc, char ***argv)
 		if (pthread_create(&display_thread, NULL, displayThread, NULL))
 			printf("Failed to create display thread.\n");
 	}
+
+	return 0;
+}
+
+void maemo_finish()
+{
+    osso_deinitialize(osso);
 }
 
 void menu_loop(void)
