@@ -32,6 +32,7 @@ int g_opts = 0;
 int g_maemo_opts;
 int bKeepDisplayOn = FALSE;
 char file_name[MAXPATHLEN];
+char keys_config_file[MAXPATHLEN] = "/opt/psx4m/keys";
 
 enum sched_action emu_action;
 void do_emu_action(void);
@@ -95,6 +96,9 @@ void PrintHelp()
     printf("                   (Default 50)\n");
 	printf("  -displayon     : Prevent display from blanking\n");
     printf("                   (Default disabled)\n");
+	printf("  -keys FILE     : File with keys configuration\n");
+    printf("                   (Default /opt/psx4m/keys)\n");
+
 
 
 	printf("\nGPU Options:\n");
@@ -247,6 +251,7 @@ int maemo_main(int argc, char **argv)
 		else if (!strcmp(argv[i], "-ydef")) 				accelOptions.y_def = atol(argv[++i]);
 		else if (!strcmp(argv[i], "-max")) 				    accelOptions.maxValue = atol(argv[++i]);
 		else if (!strcmp(argv[i], "-displayon")) 		    bKeepDisplayOn = TRUE;
+		else if (!strcmp(argv[i], "-keys")) 				sprintf(keys_config_file, "%s", argv[++i]);
 
 		else if (!strcmp(argv[i], "-spu_reverb"))           { if (atol(argv[++i]) > 0) iUseReverb = 2; }
 		else if (!strcmp(argv[i], "-spu_interpolation")) 	iUseInterpolation = atol(argv[++i]);
@@ -329,7 +334,8 @@ int maemo_main(int argc, char **argv)
 		state_slot = loadst - 1;
 	}
 
-	maemo_init(&argc, &argv);
+	if (maemo_init(&argc, &argv))
+		return 1;
 
 	if (GPU_open != NULL) {
 		int ret = GPU_open(&gpuDisp, "PCSX", NULL);
@@ -355,6 +361,7 @@ int maemo_main(int argc, char **argv)
 			do_emu_action();
 	}
 
+	maemo_finish();
 	return 0;
 }
 
